@@ -37,13 +37,9 @@ class KNativeKafkaConsumer(threading.Thread):
                     
  
         bootstrap_server=os.getenv('KAFKA_BOOTSTRAP_SERVERS',default='localhost:9092')
-        self.logger.info(bootstrap_server)
-        print(bootstrap_server)
         is_tls_enable=os.getenv('KAFKA_NET_TLS_ENABLE',default='False')
-        self.logger.info(is_tls_enable)
-        print(is_tls_enable)
         if is_tls_enable == 'True' or is_tls_enable == 'true':
-            self.security_protocol="SSL"
+            self.security_protocol='SSL'
             if 'KAFKA_NET_TLS_CA_CERT' not in os.environ:
                 raise ValueError( 'TLS CA Certificate is required!')
             if 'KAFKA_NET_TLS_CERT' not in os.environ:
@@ -51,15 +47,9 @@ class KNativeKafkaConsumer(threading.Thread):
             if 'KAFKA_NET_TLS_KEY' not in os.environ:
                 raise ValueError( 'TLS Key is required!')
             self.ssl_cafile=os.environ['KAFKA_NET_TLS_CA_CERT']
-            print(os.environ['KAFKA_NET_TLS_CA_CERT'])
-            self.logger.info(os.environ['KAFKA_NET_TLS_CA_CERT'])
             self.ssl_certfile=os.environ['KAFKA_NET_TLS_CERT']
-            print(self.ssl_certfile)
-            self.logger.info(self.ssl_certfile)
             self.ssl_keyfile=os.environ['KAFKA_NET_TLS_KEY']
-            print(self.ssl_keyfile)
-            self.logger.info(self.ssl_keyfile)
-            print("Inside if")
+ 
             self.logger.info("Inside if")
         else:
             self.security_protocol="PLAINTEXT"
@@ -73,20 +63,31 @@ class KNativeKafkaConsumer(threading.Thread):
             self.consumer=KafkaConsumer(
                           bootstrap_servers=bootstrap_server,   
                           group_id=group_id,     
-                          value_deserializer=bytes.decode,
                           security_protocol=self.security_protocol,
+                          ssl_check_hostname=True,
                           ssl_cafile=self.ssl_cafile,
                           ssl_certfile=self.ssl_certfile,
                           ssl_keyfile=self.ssl_keyfile,
                           auto_offset_reset='earliest',
                           enable_auto_commit=False)
-                            #auto_commit_interval_ms=1000)
+                         
         except KafkaError as e:
             
-            print("Inexception")
-            print("Exception while creating consumer - {}".format(e))
+            print("KafkaError")
+            print("KafkaError while creating consumer - {}".format(e))
             self.logger.error(f'Kafka Error {e}')
-            
+            self.logger.error("Houston, we have a %s", "major problem", exc_info=1)
+         except Error as er:
+            print("Error")
+            print("Error while creating consumer - {}".format(er))
+           
+            self.logger.error(f'Kafka Error {er}')
+            self.logger.error("Houston, we have a %s", "major problem", exc_info=1)
+        except Exception as ex:
+            print("Inexception")
+            print("Exception while creating consumer - {}".format(ex))
+            self.logger.error(f'Kafka Eexceptioon {ex}')
+            self.logger.error("Houston, we have a %s", "major problem", exc_info=1)
  
         print("KafkaConsumer Creation Success!")
     def getMessage(self) -> str:
